@@ -9,8 +9,10 @@ import pltrdy.time
 import pltrdy.tee
 import pltrdy.wc  # noqa F401
 import pltrdy.quiet
+import pltrdy.tmpdir
+import pltrdy.types
 
 from pltrdy.describe import describe_str, describe_lines, describe, tab_print
 from pltrdy.reload import reload_class
 
-__version__ = "0.3.3"
+__version__ = "0.3.4"
